Demo page

### Immer wieder

Immer wieder, ob wir der Liebe Landschaft auch kennen
und den kleinen Kirchhof mit seinen klagenden Namen
und die furchtbar verschweigende Schlucht, in welcher die anderen
enden: immer wieder gehn wir zu zweien hinaus
unter die alten Bäume, lagern uns immer wieder
zwischen die Blumen, gegenüber dem Himmel.

— Rainer Maria Rilke

### A vision

Two crowned Kings, and One that stood alone
With no green weight of laurels round his head,
But with sad eyes as one uncomforted,
And wearied with man's never-ceasing moan
For sins no bleating victim can atone,
And sweet long lips with tears and kisses fed.
Girt was he in a garment black and red,
And at his feet I marked a broken stone
Which sent up lilies, dove-like, to his knees.
Now at their sight, my heart being lit with flame,
I cried to Beatrice, 'Who are these? '
And she made answer, knowing well each name,
'AEschylos first, the second Sophokles,
And last (wide stream of tears!) Euripides.'

— Oscar Wilde

### Le dieu nu

Il allait en silence au milieu des risées – Il feignait d’être sourd à l’unanime affront – Il souriait avec des lèvres défrisées – Un bandeau noir ceignait les boucles de son front –

Et je lui demandai : « Jeune homme aux membres frêles Es-tu l’amour ? » -- Alors il me répondit : Non ! Je marche en me cachant à l’ombre de ses ailes, Et je suis le dieu nu qui ne dit pas son nom.

— Jean Cocteau